from django.utils.timezone import now
from django.contrib.auth import logout
from datetime import datetime
from .models import UserActivity

class AutoLogoutMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        if request.user.is_authenticated:
            now_time = now()
            last_activity = request.session.get('last_activity')

            if last_activity:
                # Convert the stored ISO string back to a datetime object
                last_activity = datetime.fromisoformat(last_activity)
                elapsed_time = (now_time - last_activity).total_seconds()
                
                if elapsed_time > 600:  # 10 minutes
                    # Log auto logout event
                    UserActivity.objects.create(
                        user=request.user,
                        event='logout',
                        timestamp=now(),
                        logout_time=now(),  # Capture the logout time
                        logout_type='auto_logout',  # Mark this as auto logout
                        browser_info=request.META.get('HTTP_USER_AGENT', 'Unknown Browser')
                    )
                    logout(request)

            # Store the current time in ISO format to track the last activity time
            request.session['last_activity'] = now_time.isoformat()

        response = self.get_response(request)
        return response
